@@ -3,9 +3,9 @@ use 5.008;
 use strict;
 use warnings;
 use Carp;
-BEGIN {
-	our $VERSION = 'v0.1.9'; # VERSION
-}
+
+our $VERSION = 'v0.1.10'; # VERSION
+
 use Moose;
 use namespace::autoclean;
 with qw(
@@ -14,8 +14,6 @@ with qw(
 
 use Business::CyberSource::Response;
 
-use SOAP::Lite; # +trace => [ 'debug' ] ;
-
 sub submit {
 	my $self = shift;
 
@@ -111,7 +109,7 @@ Business::CyberSource::Request::Capture - CyberSource Capture Request Object
 
 =head1 VERSION
 
-version v0.1.9
+version v0.1.10
 
 =head1 SYNOPSIS
 
@@ -154,7 +152,7 @@ Type: Str
 
 Reader: currency
 
-Type: MooseX::Types::Varchar::Varchar[5]
+Type: MooseX::Types::Locale::Currency::CurrencyCode
 
 This attribute is required.
 
@@ -222,7 +220,7 @@ This attribute is required.
 
 Reader: foreign_currency
 
-Type: MooseX::Types::Varchar::Varchar[5]
+Type: MooseX::Types::Locale::Currency::CurrencyCode
 
 =head2 client_name
 
